# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project uses date-based versioning.

<!-- scriv-insert-here -->

<a id='changelog-2025.12.18'></a>
## [2025.12.18] - 2025-12-18

### Fixed

- Hubspot Basic API create paramter name

<a id='changelog-2025.9.16'></a>
## [2025.9.16] - 2025-09-16

### Changed

- update dependency hubspot-api-client to v12

<a id='changelog-2025.3.17'></a>
## [2025.3.17] - 2025-03-17

- Support for Python 3.13

### Added

- Handle hubspot contacts with multiple emails

### Changed

- Updated changelog management and versioning scheme.

- Fixed a bug in hubspot error handling when performing upserts

- Updated requirements and lockfiles to support Django 4.
- Removed support for Django 2.2.

- Added posthog application.

- Update paths in pyproject.toml to ensure versioning continues to work.

- Removes unnecessary noqa's.

### added

### removed

- support for python 3.8 and 3.9.

<a id='changelog-2023.12.19'></a>
## [2023.12.19] - 2023-12-19

### Added

- Handle hubspot contacts with multiple emails

### Changed

- Updated changelog management and versioning scheme.

- Fixed a bug in hubspot error handling when performing upserts

- Updated requirements and lockfiles to support Django 4.
- Removed support for Django 2.2.

<a id='changelog-2023.5.22'></a>
## [2023.5.22] - 2023-05-22

### Added

- Handle hubspot contacts with multiple emails

### Changed

- Updated changelog management and versioning scheme.

- Fixed a bug in hubspot error handling when performing upserts

<a id='changelog-2023.5.10'></a>
## [2023.5.10] - 2023-05-10

### Added

- Handle hubspot contacts with multiple emails

### Changed

- Updated changelog management and versioning scheme.
# [Unreleased]

## [1.0.0] - 2022-07-22

### Added
- Added `mitol.hubspot_api` Hubspot API library.
